@@ -109,7 +109,7 @@ def number_to_date(number):
 
 def date_to_number(date):
     date_origin = datetime(1899, 12, 30).date()
-    number = (date - date_origin).days()
+    number = (date - date_origin).days
     return number
 
 def excel2df(filepath: str, sheet_name: str):
